﻿<#
AUTOMATION HOL - This script copies the needed files from the pipeline Drop folder to the target machine,
extracts the package, replaces the configuration file, and repackages the application again.
#>
param(
       [parameter(Mandatory=$true)]
       [string]
       # AUTOMATION HOL - Path where the package to deploy (Xap file) and configuration files are located
       $packageLocation,
       [parameter(Mandatory=$true)]
       [string]
       # AUTOMATION HOL - Temporal path to use for deployment
       $deploymentLocation,
       [parameter(Mandatory=$true)]
       [string]
       # AUTOMATION HOL - Environment where deployment is made, used to pick the corresponding configuration file from the available ones
       $environment
     )

# AUTOMATION HOL - Function to extract the contents of the xap file
function ExtractXap
{
param($sourceXapFile, $targetFolder)
    [System.Reflection.Assembly]::Load("System.IO.Compression.FileSystem,Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089") | Out-Null
    [System.IO.Compression.ZipFile]::ExtractToDirectory($sourceXapFile, $targetFolder)
}

# AUTOMATION HOL - Function to create the xap file back from the extracted contents
function PackageXap
{
param($destinationXapFile, $sourceFolder = '')
    [System.IO.Compression.ZipFile]::CreateFromDirectory($sourceFolder, $destinationXapFile)
}

# AUTOMATION HOL - Copying the package and configuration files from the package location
Copy-Item "$($packageLocation)\TreyResearch.WinPhoneClient.xap" $($deploymentLocation)
Copy-Item "$($packageLocation)\ConfigFiles\WindowsPhone\ServiceReferences.$($environment).ClientConfig" $deploymentLocation

# AUTOMATION HOL - Creating the temporary folder to copy the files, extract the xap and apply the target configuration for the environment
$tempFolder = "$($deploymentLocation)\temp"
if (!(Test-Path -path $tempFolder)) {New-Item $tempFolder -Type Directory}

# AUTOMATION HOL - Extracting the package
$packageFile = $deploymentLocation + "\TreyResearch.WinPhoneClient.xap"
ExtractXap -sourceXapFile $packageFile -targetFolder $tempFolder

# AUTOMATION HOL - Overwriting the configuration file with the one corresponding to the target environment
$sourceServiceConfig = $deploymentLocation + "\ServiceReferences." + $environment + ".ClientConfig"
$targetServiceConfig = $tempFolder + "\ServiceReferences.ClientConfig"
Copy-Item $sourceServiceConfig -Destination $targetServiceConfig -Force

# AUTOMATION HOL - Regenerating the xap package with the new configuration file
Remove-Item -Path $packageFile
PackageXap $packageFile -sourceFolder $tempFolder

# AUTOMATION HOL - Copying the script that runs the emulator from the package location, to leave it ready for the user
Copy-Item "$($packageLocation)\Deployment\WindowsPhone\DeployAndLaunchEmulator.cmd" $($deploymentLocation)
