﻿//===============================================================================
// Microsoft patterns & practices
// Guidance on Building a Release Pipeline with Team Foundation Server
//===============================================================================
// Copyright © Microsoft Corporation.  All rights reserved.
// This code released under the terms of the 
// Microsoft patterns & practices license (http://dataguidance.codeplex.com/license)
//===============================================================================


namespace TreyResearch.WinPhoneClient
{
    using System;
    using System.Collections.Generic;
    using System.Globalization;
    using System.Windows;
    using System.Windows.Controls;
    using TreyResearch.WinPhoneClient.Resources;
    using TreyResearch.WinPhoneClient.SensorReadingServiceRef;

    public partial class PivotPage
    {
        private readonly SensorReadingServiceClient _service;
        private readonly Random _readingGenerator;
        private const int MaxNum = 10000;
        private int _currentPage = 1;
        private const double PageSize = 5;
        private readonly Guid _clientId = Guid.NewGuid();
        
        public PivotPage()
        {
            InitializeComponent();
            _service = new SensorReadingServiceClient();
            _readingGenerator = new Random();
            RandomReading.Text = string.Format(CultureInfo.CurrentCulture, "{0}", _readingGenerator.Next(0, MaxNum));
            _service.GetSensorReadingsPageCompleted += OnGetSensorReadingsPageCompleted;
            _service.StoreSensorReadingCompleted += OnStoreSensorReadingCompleted;
        }

        private void OnGetSensorReadingsPageCompleted(object sender, GetSensorReadingsPageCompletedEventArgs e)
        {
            UpdateControls(e.Result);
        }

        private void OnStoreSensorReadingCompleted(object sender, System.ComponentModel.AsyncCompletedEventArgs e)
        {
            RandomReading.Text = string.Format(CultureInfo.CurrentCulture, "{0}", _readingGenerator.Next(0, MaxNum));
            ToggleNetworkStatus(isActive: false);
        }

        private void LoadSensorReadings()
        {
            ToggleNetworkStatus(isActive: true);
            _service.GetSensorReadingsPageAsync(_clientId.ToString(), _currentPage);
            ToggleNetworkStatus(isActive: false);
        }

        private void ToggleNetworkStatus(bool isActive)
        {
            NetworkActivityPost.IsIndeterminate = isActive;
            SensorReadingPivot.IsEnabled = !isActive;
        }

        private void SubmitButton_OnClick(object sender, RoutedEventArgs e)
        {
            ToggleNetworkStatus(isActive: true);
            _service.StoreSensorReadingAsync(new SensorReading()
                {
                    Id = Convert.ToInt32(RandomReading.Text),
                    CreateDate = DateTime.Now,
                    ClientId = _clientId.ToString()
                });
        }

        private void UpdateControls(dynamic resultPage)
        {
            var totalCount = Convert.ToInt32(resultPage.TotalCount);
            var totalNumberOfPages = (totalCount <= PageSize)
                ? 1
                : Math.Ceiling(totalCount / PageSize);

            PageInfo.Text = string.Format(CultureInfo.CurrentCulture,
                AppResources.PagerText,
                resultPage.TotalCount,
                _currentPage,
                totalNumberOfPages);

            Prev.IsEnabled = _currentPage > 1;
            Next.IsEnabled = _currentPage < totalNumberOfPages;

            SensorReadingList.ItemsSource = resultPage.Results;
        }

        private void UpdateControls()
        {
            SensorReadingList.ItemsSource = null;
        }

        private readonly Dictionary<string, int> _buttonPageActions = new Dictionary<string, int>
            {
                {"Prev",-1},
                {"Next",1},
            };

        private void OnBrowsePageClick(object sender, RoutedEventArgs e)
        {
            var button = (Button)sender;

            var key = button.Name;
            var increment = _buttonPageActions.ContainsKey(key) ? _buttonPageActions[key] : 0;
            _currentPage += increment;
            LoadSensorReadings();
        }

        private void SensorReadingPivot_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (SensorReadingPivot.SelectedIndex == 1)
            {
                LoadSensorReadings();
            }
        }
    }
}